#
# Copyright (c) 2007 CNRS/LAAS
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
# Matthieu Herrb - Wed Jan 10 2007
#
#
package provide wmclient 1.0

proc wmclient_open { {host localhost} } {
    set wm [socket $host 5554]
    fconfigure $wm -buffering line
    return $wm
}

proc wmclient_check_error { wm msg } {
    if {[eof $wm]} {
	error "EOF"
    }
    if { $msg != "OK" } {
	error $msg
    }
}

proc wmclient_close {wm} {
    close $wm
}

proc wmclient_list {wm} {
    puts $wm "LIST"
    while {[gets $wm line] >= 0} {
	wmclient_check_error $wm $line
	if {$line eq "OK"} break
	puts [string range $line 5 end]
    }
}

proc wmclient_move {wm name x y} {
    puts $wm "MOVE $name $x $y"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_geom {wm name x y width height} {
    puts $wm "GEOM $name $x $y $width $height"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_vdesk {wm d} {
    puts $wm "VDESK $d" 
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_todesk {wm name d} {
    puts $wm "TODESK $name $d"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_trans {wm name t} {
    puts $wm "TRANS $name $t"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_fade {wm name flag} {
    puts $wm "FADE $name $flag"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_fade2 {wm name1 name2} {
    puts $wm "TRANS $name1 $name2"
    gets $wm line
    wmclient_check_error $wm $line
}

proc wmclient_cmd {wm cmd} {
    puts $wm $cmd
    while {[gets $wm line] >= 0} {
	wmclient_check_error $wm $line
	if { $line eq "OK" } break
	puts $line
    }
}
